# Changelog

## 0.1.0 (2024-12-23)


### Features

* **🌿:** fern regeneration 12-23-2024 ([#6](https://github.com/SoferAi/soferai-py/issues/6)) ([931cb07](https://github.com/SoferAi/soferai-py/commit/931cb074f5a606ee081ab7c1ec43194c889af82c))
* basic example ([686b65b](https://github.com/SoferAi/soferai-py/commit/686b65bfe40365c30200f3d9b8f716b5bfdd91cc))
* **ci:** add release please and fernignore ([#3](https://github.com/SoferAi/soferai-py/issues/3)) ([b2a5aae](https://github.com/SoferAi/soferai-py/commit/b2a5aae3a2c41d74dee66687252cb5c9e62bd25c))
